@@ -20,7 +20,12 @@ def non_empty_value(value) -> bool:
     bool
         True if the value is not en empty string or an empty list.
     """
-    return value != '' and value is not None and value != []
+    return all([
+        value != '',
+        value is not None,
+        not isinstance(value, list) or value != [],
+        not isinstance(value, dict) or value != {}
+    ])
 
 
 def non_empty_list(values: list) -> list:
